@@ -2,7 +2,7 @@
 https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 ***/
 //{{{
-// version 0.5.6
+// version 0.5.7
 (function() {
 var getCSRFToken = function(window) {
 	// XXX: should not use RegEx - cf.
@@ -233,7 +233,7 @@ var ts = {
 					// login as that newly created user
 					ts.login(space, password, {
 						success: function() {
-							ts._register_openid_for_user(space, ts.parameters.openid);
+							ts._register_openid_for_user(space, openid);
 						},
 						errback: function() {
 							throw "failed at step 2/3";
